<?php

$lan = array(
  'Top 50 domains with more than 5 emails' => 'Os 50 sites com mais de 5 emails',
  'num' => 'num',
  'perc' => '%',
);
?>
